@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006-2008 Vlad Vasiliev
- * Copyright (C) 2006-2008 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * Copyright (C) 2008      Andrew Olmsted
  * 	for the code
  *        
@@ -32,10 +32,11 @@
 /*******************************************************************************/
 #include "weather-common.h"
 /*******************************************************************************/
-#define GCONF_KEY_PREFIX		"/apps/maemo/omweather"
-#define GCONF_KEY_HTTP_PROXY_PREFIX	"/system/http_proxy"
-#define GCONF_KEY_CLOCK_PREFIX		"/apps/osso/clock"
-#define GCONF_KEY_WEATHER_DIR_NAME		GCONF_KEY_PREFIX"/weather-dir"
+#define GCONF_KEY_PREFIX                        "/apps/maemo/omweather"
+#define GCONF_KEY_HTTP_PROXY_PREFIX             "/system/http_proxy"
+#define GCONF_KEY_PROXY_PREFIX                  "/system/proxy"
+#define GCONF_KEY_CLOCK_PREFIX                  "/apps/osso/clock"
+#define GCONF_KEY_WEATHER_DIR_NAME              GCONF_KEY_PREFIX"/weather-dir"
 #define GCONF_KEY_WEATHER_CURRENT_COUNTRY_NAME	GCONF_KEY_PREFIX"/current-country-name"
 #define GCONF_KEY_WEATHER_CURRENT_SOURCE_NAME	GCONF_KEY_PREFIX"/current-source-name"
 #define GCONF_KEY_WEATHER_STATE_NAME		GCONF_KEY_PREFIX"/state-name"
@@ -70,14 +71,15 @@
 #define GCONF_KEY_WEATHER_PROGRAM_VERSION	GCONF_KEY_PREFIX"/version"
 #define GCONF_KEY_WEATHER_SETTING_TAB_NUMBER	GCONF_KEY_PREFIX"/settings-tab-number"
 #if defined(OS2008) || defined(DEBUGTEMP) || defined(OS2009)
-#define GCONF_KEY_USE_SENSOR			GCONF_KEY_PREFIX"/use-sensor"
-#define GCONF_KEY_DISPLAY_SENSOR_AT		GCONF_KEY_PREFIX"/display-sensor-at"
-#define GCONF_KEY_SENSOR_UPDATE_TIME		GCONF_KEY_PREFIX"/sensor-update-time"
+#define GCONF_KEY_USE_SENSOR            GCONF_KEY_PREFIX"/use-sensor"
+#define GCONF_KEY_DISPLAY_SENSOR_AT     GCONF_KEY_PREFIX"/display-sensor-at"
+#define GCONF_KEY_SENSOR_UPDATE_TIME    GCONF_KEY_PREFIX"/sensor-update-time"
 #endif
-#define GCONF_KEY_WEATHER_SWITCH_TIME		GCONF_KEY_PREFIX"/switch-time"
-#define GCONF_KEY_HTTP_PROXY_ON			GCONF_KEY_HTTP_PROXY_PREFIX"/use_http_proxy"
-#define GCONF_KEY_HTTP_PROXY_HOST		GCONF_KEY_HTTP_PROXY_PREFIX"/host"
-#define GCONF_KEY_HTTP_PROXY_PORT		GCONF_KEY_HTTP_PROXY_PREFIX"/port"
+#define GCONF_KEY_WEATHER_SWITCH_TIME   GCONF_KEY_PREFIX"/switch-time"
+#define GCONF_KEY_PROXY_MODE            GCONF_KEY_PROXY_PREFIX"/mode"
+#define GCONF_KEY_HTTP_PROXY_ON         GCONF_KEY_HTTP_PROXY_PREFIX"/use_http_proxy"
+#define GCONF_KEY_HTTP_PROXY_HOST       GCONF_KEY_HTTP_PROXY_PREFIX"/host"
+#define GCONF_KEY_HTTP_PROXY_PORT       GCONF_KEY_HTTP_PROXY_PREFIX"/port"
 #define GCONF_KEY_CLOCK_REMOTE_LOCATION		GCONF_KEY_CLOCK_PREFIX"/remote-location"
 #define GCONF_KEY_CLOCK_HOME_LOCATION		GCONF_KEY_CLOCK_PREFIX"/home-location"
 #define GCONF_KEY_DOWNLOADING_AFTER_CONNECTING  GCONF_KEY_PREFIX"/downloading-after-connecting"
