@@ -1,8 +1,8 @@
 /* vim: set sw=4 ts=4 et: */
 /* This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006-2008 Vlad Vasiliev
- * Copyright (C) 2006-2008 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * 	for the code
  *        
  * Copyright (C) 2008 Andrew Zhilin
@@ -33,45 +33,50 @@
 #endif
 /*******************************************************************************/
 #ifdef ENABLE_GPS
-#ifdef OS2008
 
-void get_nearest_station(double lat, double lon, Station * result) {
-    FILE *fh;
-    char buffer[512];
-    char filename[4096];
+void
+get_nearest_station(double lat, double lon, Station *result) {
+
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
     Region_item region;
     GtkListStore *stations_list = NULL;
-    GtkTreeIter iter;
-    gboolean valid;
-    gchar *station_name = NULL, *station_id0 = NULL;
+    GtkListStore *regions_list = NULL;
+    GtkTreeIter iter, iter_region;
+    gboolean valid, valid_region;
+    int regions_number;
+    int region_id;
+    gchar *station_name = NULL, *station_id0 = NULL, *region_name;
     double station_latitude, station_longtitude, distance, min_distance =
         40000;
+    sqlite3    *database = NULL;
 
-    filename[0] = 0;
-    snprintf(filename, sizeof(filename) - 1, "%s%s",
-             DATABASEPATH,
-             REGIONSFILE);
-    fh = fopen(filename, "rt");
-    if (!fh) {
-        fprintf(stderr, "\nCan't read file %s: %s", filename,
-                strerror(errno));
+    /* Check only weather.com datase yet */
+    database = open_database(DATABASEPATH, "weather.com.db");
+    if (!database)
         return;
-    }
+    regions_list = create_regions_list(database, 0, &regions_number);
+    if (!regions_list)
+        return;
+    valid_region = gtk_tree_model_get_iter_first(GTK_TREE_MODEL
+                                              (regions_list), &iter_region);
+
     /* Reading region settings */
-    while (!feof(fh)) {
-        memset(buffer, 0, sizeof(buffer));
-        fgets(buffer, sizeof(buffer) - 1, fh);
-        parse_region_string(buffer, &region);
+    while (valid_region) {
+        gtk_tree_model_get(GTK_TREE_MODEL(regions_list),
+                                   &iter_region,
+                                   0, &region_name,
+                                   1, &region_id,
+                                   2, &region.maxlon,
+                                   3, &region.maxlat,
+                                   4, &region.minlon,
+                                   5, &region.minlat,
+                                   -1);
         /* Checking insiding point in to region */
-        if (lat >= region.minlat && lat <= region.maxlat
-            && lon >= region.minlon && lon <= region.maxlon) {
-            stations_list =
-                create_items_list(DATABASEPATH,
-                                  LOCATIONSFILE, region.start, region.end,
-                                  NULL);
+        if (lat >= (region.minlat -1) && lat <= (region.maxlat + 1)
+            && lon >= (region.minlon - 1) && lon <= (region.maxlon + 1) ) {
+            stations_list = create_stations_list(database, region_id);
             valid =
                 gtk_tree_model_get_iter_first(GTK_TREE_MODEL
                                               (stations_list), &iter);
@@ -87,13 +92,14 @@ void get_nearest_station(double lat, double lon, Station * result) {
                 distance =
                     calculate_distance(lat, lon, station_latitude,
                                        station_longtitude);
+
                 if (distance < min_distance) {
 
                     /* New minimal distance */
                     min_distance = distance;
 
                     /* Copying to result */
-                    memset(result->name, 0, sizeof(result->name) + 5);
+                    memset(result->name, 0, sizeof(result->name));
                     memcpy(result->name, station_name,
                            ((sizeof(result->name) - 1) >
                             (int)(strlen(station_name))
@@ -124,7 +130,6 @@ void get_nearest_station(double lat, double lon, Station * result) {
                     result->latitude = station_latitude;
                     result->longtitude = station_longtitude;
                 }
-
                 valid =
                     gtk_tree_model_iter_next(GTK_TREE_MODEL
                                              (stations_list), &iter);
@@ -136,8 +141,11 @@ void get_nearest_station(double lat, double lon, Station * result) {
                 stations_list = NULL;
             }
         }
+        valid_region =
+            gtk_tree_model_iter_next(GTK_TREE_MODEL
+                                     (regions_list), &iter_region);
     }
-    fclose(fh);
+    close_database(database);
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -148,6 +156,7 @@ gps_location_started (LocationGPSDControl *control, gpointer userdata)
 {
  initial_gps_connect();
 }
+
 static void 
 gps_location_stopped (LocationGPSDControl *control, gpointer userdata)
 {
@@ -155,8 +164,9 @@ gps_location_stopped (LocationGPSDControl *control, gpointer userdata)
 }
 
 /*******************************************************************************/ 
+void
 initial_gps_control(void)
-{ 
+{
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -190,6 +200,7 @@ gps_location_changed(LocationGPSDevice * device, gpointer userdata) {
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
+
     if (!app->config->gps_station)
         return;
     if (device->fix->fields & LOCATION_GPS_DEVICE_LATLONG_SET) {
@@ -201,7 +212,7 @@ gps_location_changed(LocationGPSDevice * device, gpointer userdata) {
 /*******************************************************************************/
 void
 initial_gps_connect(void)
-{ 
+{
 #ifdef DEBUGFUNCTIONCALL
     START_FUNCTION;
 #endif
@@ -220,9 +231,9 @@ deinitial_gps_connect(void)
     START_FUNCTION;
 #endif
     if (app->gps_device){
-	g_signal_handler_disconnect (app->gps_device,app->gps_id_connection);
-	g_object_unref(app->gps_device);
-    }	
+        g_signal_handler_disconnect (app->gps_device,app->gps_id_connection);
+        g_object_unref(app->gps_device);
+    }
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 #endif
@@ -289,4 +300,3 @@ void delete_all_gps_stations(void) {
 
 /*******************************************************************************/
 #endif
-#endif
