@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006 Vlad Vasiliev
- * Copyright (C) 2006 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * 	for the code
  *        
  * Copyright (C) 2008 Andrew Zhilin
@@ -32,6 +32,10 @@
 #include "weather-common.h"
 #include <gdk/gdkx.h>
 #include <X11/Xatom.h>
+
 /*******************************************************************************/
 void init_portrait(GtkWidget *win);
+void init_landscape(GtkWidget *win);
+void check_device_position(DBusConnection *connection);
+DBusHandlerResult get_mce_signal_cb(DBusConnection *conn, DBusMessage *msg, gpointer data);
 #endif
