@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006 Vlad Vasiliev
- * Copyright (C) 2006 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * 	for the code
  *        
  * Copyright (C) 2008 Andrew Zhilin
@@ -317,14 +317,17 @@ int parse_station_string(const char *string, Station * result) {
 sqlite3* open_database(const char *path, const char *filename){
     sqlite3	*db = NULL;
     gchar	name[256];
-
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
     if(!path || !filename)
-	return NULL;
+        return NULL;
     *name = 0;
     snprintf(name, sizeof(name) - 1, "%s%s", path, filename);
-    if(sqlite3_open(name, &db))
-	return NULL;		/* error */
-
+    if(sqlite3_open(name, &db)){
+        fprintf(stderr,"Error in connection to database %s\n",sqlite3_errmsg(db));
+        return NULL;   /* error */
+    }
     return db;
 }
 /*******************************************************************************/
@@ -361,24 +364,40 @@ GtkListStore* create_regions_list(sqlite3 *database, int country_id, int *region
     gchar		sql[256];
     struct request_data	data = { 0, 0 };
 
-    if(!database || !country_id)
-	return NULL;	/* database doesn't open */
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
 
-    list = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_INT);
+    if(!database)
+        return NULL;    /* database doesn't open */
+
+    list = gtk_list_store_new(6, G_TYPE_STRING, G_TYPE_INT, G_TYPE_DOUBLE, G_TYPE_DOUBLE, 
+                                 G_TYPE_DOUBLE, G_TYPE_DOUBLE);
     data.list = list;
     *sql = 0;
-    snprintf(sql, sizeof(sql) - 1,
-		"SELECT id, name FROM regions WHERE country_id = %d ORDER BY name",
-		country_id);
+    if (country_id == 0)
+        snprintf(sql, sizeof(sql) - 1,
+                 "SELECT id, name, longititudemax, latitudemax, longititudemin, latitudemin \
+                  FROM regions");
+    else
+        snprintf(sql, sizeof(sql) - 1,
+                 "SELECT id, name, longititudemax, latitudemax, longititudemin, latitudemin \
+                  FROM regions WHERE country_id = %d ORDER BY name",
+                  country_id);
     rc = sqlite3_exec(database, sql, regions_callback, (void*)&data, &errMsg);
     if(rc != SQLITE_OK){
 #ifndef RELEASE
-	fprintf(stderr, "\n>>>>%s\n", errMsg);
+        fprintf(stderr, "\n>>>>%s\n", errMsg);
 #endif
-	sqlite3_free(errMsg);
-	return NULL;
+        sqlite3_free(errMsg);
+        return NULL;
     }
     *region_count = data.count;
+
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
+
     return list;
 }
 /*******************************************************************************/
@@ -388,6 +407,10 @@ GtkListStore* create_stations_list(sqlite3 *database, int region_id){
     gchar		*errMsg = NULL;
     gchar		sql[256];
 
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
     if(!database || !region_id)
 	return NULL;	/* database doesn't open */
 
@@ -400,11 +423,14 @@ GtkListStore* create_stations_list(sqlite3 *database, int region_id){
     rc = sqlite3_exec(database, sql, stations_callback, (void*)list, &errMsg);
     if(rc != SQLITE_OK){
 #ifndef RELEASE
-	fprintf(stderr, "\n>>>>%s\n", errMsg);
+	    fprintf(stderr, "\n>>>>%s\n", errMsg);
 #endif
-	sqlite3_free(errMsg);
-	return NULL;
+    	sqlite3_free(errMsg);
+	    return NULL;
     }
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
     return list;
 }
 /*******************************************************************************/
@@ -460,15 +486,32 @@ int regions_callback(void *user_data, int argc, char **argv, char **azColName){
     struct request_data	*data = (struct request_data*)user_data;
     GtkListStore	*list = GTK_LIST_STORE(data->list);
 
+#ifdef DEBUGFUNCTIONCALL
+    START_FUNCTION;
+#endif
+
+	setlocale(LC_NUMERIC, "POSIX");
     data->count += (int)argc / 2;
 /* add new item for each first element */
     gtk_list_store_append(list, &iter);
     for(i = 0; i < argc; i++){
-	if(!strcmp(azColName[i], "id"))
-	    gtk_list_store_set(list, &iter, 1, atoi(argv[i]), -1);
-	if(!strcmp(azColName[i], "name"))
-	    gtk_list_store_set(list, &iter, 0, argv[i], -1);
+        if(!strcmp(azColName[i], "id"))
+            gtk_list_store_set(list, &iter, 1, atoi(argv[i]), -1);
+        if(!strcmp(azColName[i], "name"))
+            gtk_list_store_set(list, &iter, 0, argv[i], -1);
+        if(!strcmp(azColName[i], "longititudemax"))
+            gtk_list_store_set(list, &iter, 2, atof(argv[i]), -1);
+        if(!strcmp(azColName[i], "latitudemax"))
+            gtk_list_store_set(list, &iter, 3, atof(argv[i]), -1);
+        if(!strcmp(azColName[i], "longititudemin"))
+            gtk_list_store_set(list, &iter, 4, atof(argv[i]), -1);
+        if(!strcmp(azColName[i], "latitudemin"))
+            gtk_list_store_set(list, &iter, 5, atof(argv[i]), -1);
     }
+	setlocale(LC_NUMERIC, "");
+#ifdef DEBUGFUNCTIONCALL
+    END_FUNCTION;
+#endif
     return 0;
 }
 /*******************************************************************************/
@@ -479,7 +522,7 @@ int stations_callback(void *user_data, int argc, char **argv, char **azColName){
 
 /* add new item for each first element */
     gtk_list_store_append(list, &iter);
-
+	setlocale(LC_NUMERIC, "POSIX");
     for(i = 0; i < argc; i++){
 	if(!strcmp(azColName[i], "name"))
 	    gtk_list_store_set(list, &iter, 0, argv[i], -1);
@@ -490,6 +533,7 @@ int stations_callback(void *user_data, int argc, char **argv, char **azColName){
 	if(!strcmp(azColName[i], "latitude"))
 	    gtk_list_store_set(list, &iter, 3, atof(argv[i]), -1);
     }
+	setlocale(LC_NUMERIC, "");
     return 0;
 }
 /*******************************************************************************/
