@@ -2,8 +2,8 @@
 /*
  * This file is part of Other Maemo Weather(omweather)
  *
- * Copyright (C) 2006 Vlad Vasiliev
- * Copyright (C) 2006 Pavel Fialko
+ * Copyright (C) 2006-2009 Vlad Vasiliev
+ * Copyright (C) 2006-2009 Pavel Fialko
  * Copyright (C) 2008 Andrew Olmsted
  * 	for the code
  *        
@@ -41,6 +41,7 @@ gboolean draw_top_gradient(GtkWidget *widget, GdkEventExpose *event);
 gboolean draw_bottom_gradient(GtkWidget *widget, GdkEventExpose *event);
 void set_background_color(GtkWidget *widget, GdkColor *bgc);
 void set_font_color(GtkWidget *widget, guint16 red, guint16 green, guint16 blue);
+void change_state_window(GtkWidget *window);
 float c2f(float temp);
 void swap_temperature(int *hi, int *low);
 GtkWidget* lookup_widget(GtkWidget* widget, const gchar* widget_name);
@@ -62,5 +63,7 @@ int create_icon_set_list(gchar *dir_path, GSList **store, gchar *type); /* scan
 void update_icons_set_base(const char *icon_set_name);
 GtkWidget *create_icon_widget(GdkPixbuf *icon_buffer, const char *icon_path, int icon_size, GSList **objects_list);
 extern GtkWidget *create_clutter_main_icon(GdkPixbuf *icon_buffer, const char *icon_path, int icon_size, GSList **objects_list);
+
+void write_log(char *string);
 /*******************************************************************************/
 #endif
